==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/GrowableArrayContext.h <==
// class gnu.java.beans.decoder.GrowableArrayContext

// class file dependencies
// @dep_class f38552320b706ae7 gnu_java_beans_decoder_AbstractContext
// @dep_class 3034b4dda12a1f79 gnu_java_beans_decoder_GrowableArrayContext
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractContext

#include "gnu/java/beans/decoder/AbstractContext.h"

#ifndef _JC_gnu_java_beans_decoder_GrowableArrayContext_H_
#define _JC_gnu_java_beans_decoder_GrowableArrayContext_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_GrowableArrayContext$sub_refs	_jc_gnu_java_beans_decoder_GrowableArrayContext$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_GrowableArrayContext$sub_nonrefs	_jc_gnu_java_beans_decoder_GrowableArrayContext$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_GrowableArrayContext$refs	_jc_gnu_java_beans_decoder_GrowableArrayContext$refs;
typedef struct _jc_gnu_java_beans_decoder_GrowableArrayContext$nonrefs	_jc_gnu_java_beans_decoder_GrowableArrayContext$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object	_jc_gnu_java_beans_decoder_GrowableArrayContext$object;

typedef struct _jc_gnu_java_beans_decoder_GrowableArrayContext$fields_struct	_jc_gnu_java_beans_decoder_GrowableArrayContext$fields_struct;
typedef const struct _jc_gnu_java_beans_decoder_GrowableArrayContext$vmethods	_jc_gnu_java_beans_decoder_GrowableArrayContext$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_GrowableArrayContext$vtable	_jc_gnu_java_beans_decoder_GrowableArrayContext$vtable;
typedef const struct _jc_gnu_java_beans_decoder_GrowableArrayContext$vtype	_jc_gnu_java_beans_decoder_GrowableArrayContext$vtype;

// Class fields structure
struct _jc_gnu_java_beans_decoder_GrowableArrayContext$fields_struct {
	jint	INITIAL__5fSIZE;
};
extern _jc_gnu_java_beans_decoder_GrowableArrayContext$fields_struct _jc_gnu_java_beans_decoder_GrowableArrayContext$class_fields;

// Constructors
extern void _jc_gnu_java_beans_decoder_GrowableArrayContext$method$_init$ed29e6e80382d6fd(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Class$object *);

// Virtual methods
extern void _jc_gnu_java_beans_decoder_GrowableArrayContext$method$addParameterObject$4706d521eeccfb00(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_GrowableArrayContext$method$endContext$404ed46ecd22657f(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_GrowableArrayContext$method$get$a706240e1333824b(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, jint);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_GrowableArrayContext$method$getResult$945d2e60d6ab8d5c(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *);
extern void _jc_gnu_java_beans_decoder_GrowableArrayContext$method$notifyStatement$516a25c30df0911b(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, struct _jc_object *);
extern void _jc_gnu_java_beans_decoder_GrowableArrayContext$method$set$bdfa7111d1276910(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, jint, struct _jc_java_lang_Object$object *);
extern jboolean _jc_gnu_java_beans_decoder_GrowableArrayContext$method$subContextFailed$dac667c9783c2a33(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_GrowableArrayContext$method_info$addParameterObject$4706d521eeccfb00;
extern _jc_method _jc_gnu_java_beans_decoder_GrowableArrayContext$method_info$endContext$404ed46ecd22657f;
extern _jc_method _jc_gnu_java_beans_decoder_GrowableArrayContext$method_info$get$a706240e1333824b;
extern _jc_method _jc_gnu_java_beans_decoder_GrowableArrayContext$method_info$getResult$945d2e60d6ab8d5c;
extern _jc_method _jc_gnu_java_beans_decoder_GrowableArrayContext$method_info$notifyStatement$516a25c30df0911b;
extern _jc_method _jc_gnu_java_beans_decoder_GrowableArrayContext$method_info$set$bdfa7111d1276910;
extern _jc_method _jc_gnu_java_beans_decoder_GrowableArrayContext$method_info$subContextFailed$dac667c9783c2a33;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_GrowableArrayContext$vmethods {
	void	(*addParameterObject$4706d521eeccfb00)(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*endContext$404ed46ecd22657f)(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*get$a706240e1333824b)(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, jint);
	struct _jc_java_lang_Object$object	*(*getResult$945d2e60d6ab8d5c)(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *);
	void	(*notifyStatement$516a25c30df0911b)(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, struct _jc_object *);
	void	(*set$bdfa7111d1276910)(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, jint, struct _jc_java_lang_Object$object *);
	jboolean	(*subContextFailed$dac667c9783c2a33)(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_GrowableArrayContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractContext$vmethods	gnu_java_beans_decoder_AbstractContext;
	_jc_gnu_java_beans_decoder_GrowableArrayContext$vmethods	gnu_java_beans_decoder_GrowableArrayContext;
};

// Vtype
struct _jc_gnu_java_beans_decoder_GrowableArrayContext$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_GrowableArrayContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_GrowableArrayContext$sub_refs {
	struct _jc_java_lang_Class$object	*klass;
	struct _jc_java_lang_Object$object	*array;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_GrowableArrayContext$refs {
    _jc_gnu_java_beans_decoder_GrowableArrayContext$sub_refs	gnu_java_beans_decoder_GrowableArrayContext;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_refs	gnu_java_beans_decoder_AbstractContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_GrowableArrayContext$sub_nonrefs {
	jint	length;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_GrowableArrayContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs	gnu_java_beans_decoder_AbstractContext;
    _jc_gnu_java_beans_decoder_GrowableArrayContext$sub_nonrefs	gnu_java_beans_decoder_GrowableArrayContext;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object {
	_jc_gnu_java_beans_decoder_GrowableArrayContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_GrowableArrayContext$vtype	*vtype;
	_jc_gnu_java_beans_decoder_GrowableArrayContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_GrowableArrayContext$vtype _jc_gnu_java_beans_decoder_GrowableArrayContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_GrowableArrayContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_GrowableArrayContext$class_object;

#endif	/* _JC_gnu_java_beans_decoder_GrowableArrayContext_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/GrowableArrayContext.h <==
// class gnu.java.beans.decoder.GrowableArrayContext

// class file dependencies
// @dep_class f38552320b706ae7 gnu_java_beans_decoder_AbstractContext
// @dep_class 3034b4dda12a1f79 gnu_java_beans_decoder_GrowableArrayContext
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractContext

#include "gnu/java/beans/decoder/AbstractContext.h"

#ifndef _JC_gnu_java_beans_decoder_GrowableArrayContext_H_
#define _JC_gnu_java_beans_decoder_GrowableArrayContext_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_GrowableArrayContext$sub_refs	_jc_gnu_java_beans_decoder_GrowableArrayContext$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_GrowableArrayContext$sub_nonrefs	_jc_gnu_java_beans_decoder_GrowableArrayContext$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_GrowableArrayContext$refs	_jc_gnu_java_beans_decoder_GrowableArrayContext$refs;
typedef struct _jc_gnu_java_beans_decoder_GrowableArrayContext$nonrefs	_jc_gnu_java_beans_decoder_GrowableArrayContext$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object	_jc_gnu_java_beans_decoder_GrowableArrayContext$object;

typedef struct _jc_gnu_java_beans_decoder_GrowableArrayContext$fields_struct	_jc_gnu_java_beans_decoder_GrowableArrayContext$fields_struct;
typedef const struct _jc_gnu_java_beans_decoder_GrowableArrayContext$vmethods	_jc_gnu_java_beans_decoder_GrowableArrayContext$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_GrowableArrayContext$vtable	_jc_gnu_java_beans_decoder_GrowableArrayContext$vtable;
typedef const struct _jc_gnu_java_beans_decoder_GrowableArrayContext$vtype	_jc_gnu_java_beans_decoder_GrowableArrayContext$vtype;

// Class fields structure
struct _jc_gnu_java_beans_decoder_GrowableArrayContext$fields_struct {
	jint	INITIAL__5fSIZE;
};
extern _jc_gnu_java_beans_decoder_GrowableArrayContext$fields_struct _jc_gnu_java_beans_decoder_GrowableArrayContext$class_fields;

// Constructors
extern void _jc_gnu_java_beans_decoder_GrowableArrayContext$method$_init$ed29e6e80382d6fd(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_beans_decoder_GrowableArrayContext$method$addParameterObject$4706d521eeccfb00(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_GrowableArrayContext$method$endContext$404ed46ecd22657f(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_GrowableArrayContext$method$get$a706240e1333824b(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_GrowableArrayContext$method$getResult$945d2e60d6ab8d5c(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_decoder_GrowableArrayContext$method$notifyStatement$516a25c30df0911b(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_decoder_GrowableArrayContext$method$set$bdfa7111d1276910(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_beans_decoder_GrowableArrayContext$method$subContextFailed$dac667c9783c2a33(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_GrowableArrayContext$method_info$addParameterObject$4706d521eeccfb00;
extern _jc_method _jc_gnu_java_beans_decoder_GrowableArrayContext$method_info$endContext$404ed46ecd22657f;
extern _jc_method _jc_gnu_java_beans_decoder_GrowableArrayContext$method_info$get$a706240e1333824b;
extern _jc_method _jc_gnu_java_beans_decoder_GrowableArrayContext$method_info$getResult$945d2e60d6ab8d5c;
extern _jc_method _jc_gnu_java_beans_decoder_GrowableArrayContext$method_info$notifyStatement$516a25c30df0911b;
extern _jc_method _jc_gnu_java_beans_decoder_GrowableArrayContext$method_info$set$bdfa7111d1276910;
extern _jc_method _jc_gnu_java_beans_decoder_GrowableArrayContext$method_info$subContextFailed$dac667c9783c2a33;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_GrowableArrayContext$vmethods {
	void	(*addParameterObject$4706d521eeccfb00)(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*endContext$404ed46ecd22657f)(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*get$a706240e1333824b)(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getResult$945d2e60d6ab8d5c)(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *) _JC_JCNI_ATTR;
	void	(*notifyStatement$516a25c30df0911b)(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*set$bdfa7111d1276910)(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jboolean	(*subContextFailed$dac667c9783c2a33)(_jc_env *, struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_GrowableArrayContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractContext$vmethods	gnu_java_beans_decoder_AbstractContext;
	_jc_gnu_java_beans_decoder_GrowableArrayContext$vmethods	gnu_java_beans_decoder_GrowableArrayContext;
};

// Vtype
struct _jc_gnu_java_beans_decoder_GrowableArrayContext$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_GrowableArrayContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_GrowableArrayContext$sub_refs {
	struct _jc_java_lang_Class$object	*klass;
	struct _jc_java_lang_Object$object	*array;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_GrowableArrayContext$refs {
    _jc_gnu_java_beans_decoder_GrowableArrayContext$sub_refs	gnu_java_beans_decoder_GrowableArrayContext;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_refs	gnu_java_beans_decoder_AbstractContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_GrowableArrayContext$sub_nonrefs {
	jint	length;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_GrowableArrayContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs	gnu_java_beans_decoder_AbstractContext;
    _jc_gnu_java_beans_decoder_GrowableArrayContext$sub_nonrefs	gnu_java_beans_decoder_GrowableArrayContext;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_GrowableArrayContext$object {
	_jc_gnu_java_beans_decoder_GrowableArrayContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_GrowableArrayContext$vtype	*vtype;
	_jc_gnu_java_beans_decoder_GrowableArrayContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_GrowableArrayContext$vtype _jc_gnu_java_beans_decoder_GrowableArrayContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_GrowableArrayContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_GrowableArrayContext$class_object;

#endif	/* _JC_gnu_java_beans_decoder_GrowableArrayContext_H_ */
